/*
 * Macro parameters:
 *   P     PV name prefix (e.g. "17ida:")
 *   A     Auto beam positioner name (e.g. Abp1)
 *   BPPG  Beam positioning permit granter (e.g. ioc23:Bppg)
 */

/* General constants */

#define AUTOBP_PROC_VALUE 1

/* General timeout and delay constants */

#define AUTOBP_POSITIONING_TIMEOUT              60.0 /* in seconds */
#define AUTOBP_OBTAIN_PERMIT_TIMEOUT           195.0 /* in seconds */
#define AUTOBP_RELEASE_PERMIT_RESPONSE_TIMEOUT  10.0 /* in seconds */
#define AUTOBP_DEP_ABP_PAUSE_TIMEOUT            60.0 /* in seconds */
#define AUTOBP_SCANNING_TIMEOUT                 60.0 /* in seconds */

#define AUTOBP_INITIALIZE_DELAY                  5.0 /* in seconds */
#define AUTOBP_REPEAT_OPTIMIZATION_SCAN_DELAY    1.0 /* in seconds */

/* State constants */

#define AUTOBP_STATE_SUSPENDED       0
#define AUTOBP_STATE_MONITORING      1
#define AUTOBP_STATE_CORRECTING      2
#define AUTOBP_STATE_GETTING_PERMIT  3
#define AUTOBP_STATE_DELAYING        4
#define AUTOBP_STATE_PAUSED          5
#define AUTOBP_STATE_PAUSING_DEP_ABP 6
#define AUTOBP_STATE_SCANNING        7

/* Busy constants */

#define AUTOBP_BUSY_NO  0
#define AUTOBP_BUSY_YES 1

/* Sscan constants */

#define AUTOBP_SCAN_EXSC_ABORT 0
#define AUTOBP_SCAN_EXSC_START 1

#define AUTOBP_SCAN_ALERT_NO  0
#define AUTOBP_SCAN_ALERT_YES 1

#define AUTOBP_SCAN_ABORT_TIMEOUT 5.0
#define AUTOBP_SCAN_ABORT_FORCED_DELAY 2.0

/* BPPG protocol constants */

#define AUTOBP_BPPG_IN_NO_MESSAGE 0
#define AUTOBP_BPPG_IN_REQUEST    1
#define AUTOBP_BPPG_IN_RELEASE    2

#define AUTOBP_BPPG_OUT_NO_MESSAGE 0
#define AUTOBP_BPPG_OUT_GRANTED    1
#define AUTOBP_BPPG_OUT_RELEASE_OK 2
#define AUTOBP_BPPG_OUT_REVOKED    3
#define AUTOBP_BPPG_OUT_RESET      4

/* SNCSEQ constants */

#define AUTOBP_SNCSEQ_PV_STAT_OK 0 /* Must match pvStatOK in
                                    * include/pvAlarm.h */

/* Status variables */

short State; assign State to "{P}{A}:State";

string Log; assign Log to "{P}{A}:Log";

/* Configuration variables */

double CorrDly; assign CorrDly to "{P}{A}:CorrDly";
  monitor CorrDly;

/* Control variables */

short Abort; assign Abort to "{P}{A}:Abort";
  monitor Abort;
  evflag AbortRequested;
  sync Abort AbortRequested;

short ExtPauseNeeded; assign ExtPauseNeeded to "{P}{A}:ExtPauseNeeded";
  monitor ExtPauseNeeded;

/* BPPG protocol variables */

short BppgIn; assign BppgIn to "{BPPG}:In";
short BppgOut; assign BppgOut to "{BPPG}:Out";
  monitor BppgOut;

/* Support variables */

int Status;
int LogIdx;
